@@ -80,8 +80,10 @@ class ZestRunner:
         if curr_depth < last_depth:
             s(f"\n{'  ' * curr_depth}")
 
-        if hasattr(func, "skip"):
-            s(bold, yellow, "SKIPPED ", getattr(func, "skip_reason") or "")
+        if isinstance(error, str) and error.startswith("skipped"):
+            s(bold, yellow, error)
+        elif hasattr(func, "skip"):
+            s(bold, yellow, "SKIPPED ", getattr(func, "skip_reason", "") or "")
         elif error:
             s(bold, red, "ERROR")
         else:
@@ -192,7 +194,17 @@ class ZestRunner:
         elif self.verbose == 1:
             self.display_abbreviated(name, error, func)
 
-    def _recurse_ast(self, func_body, parent_name):
+    def _recurse_ast(self, func_body, parent_name, skips):
+        """
+        Args:
+            func_body: the AST func_body or module body
+            parent_name: The parent function name or None if a module
+            skips: a list of skip names for the current func_body or None if module
+
+        Returns:
+            list of children: [(full_name, _groups, skips)]
+
+        """
         n_test_funcs = 0
         found_zest_call = False
         found_zest_call_before_final_func_def = False
@@ -207,27 +219,29 @@ class ZestRunner:
                     if not part.name.startswith("_"):
                         full_name = f"{parent_name}.{part.name}"
 
-                groups = []
-                skips = []
+                _groups = []
+                _skips = []
                 if part.decorator_list:
                     for dec in part.decorator_list:
                         if isinstance(dec, ast.Call):
                             if isinstance(dec.func, ast.Attribute):
                                 if dec.func.attr == "group":
                                     if isinstance(dec.args[0], ast.Str):
-                                        groups += [dec.args[0].s]
+                                        _groups += [dec.args[0].s]
                                 elif dec.func.attr == "skip":
-                                    if isinstance(dec.args[0], ast.Str):
-                                        skips += [dec.args[0].s]
-
-                if len(skips) > 0:
-                    if self.bypass_skip is None or skips[0] != self.bypass_skip:
-                        continue
+                                    if len(dec.args) > 0 and isinstance(
+                                        dec.args[0], ast.Str
+                                    ):
+                                        _skips += [dec.args[0].s]
+                                    elif len(dec.keywords) > 0 and isinstance(
+                                        dec.keywords[0].value, ast.Str
+                                    ):
+                                        _skips += [dec.keywords[0].value.s]
 
                 if full_name is not None:
-                    child_list += [(full_name, groups)]
+                    child_list += [(full_name, set(_groups), _skips)]
                     n_test_funcs += 1
-                    child_list += self._recurse_ast(part.body, full_name)
+                    child_list += self._recurse_ast(part.body, full_name, _skips)
 
                 if found_zest_call:
                     found_zest_call_before_final_func_def = True
@@ -238,7 +252,12 @@ class ZestRunner:
                         if part.value.func.id == "zest":
                             found_zest_call = True
 
-        if n_test_funcs > 0 and parent_name is not None and not found_zest_call:
+        if (
+            n_test_funcs > 0
+            and parent_name is not None
+            and not found_zest_call
+            and (not skips or (skips and self.bypass_skip is not None and self.bypass_skip in skips))
+        ):
             ZestRunner.n_zest_missing_errors += 1
             if found_zest_call_before_final_func_def:
                 s(
@@ -259,10 +278,10 @@ class ZestRunner:
         include_dirs=None,
         match_string=None,
         recurse=0,
-        groups=None,
+        run_groups=None,
+        skip_groups=None,
         disable_shuffle=False,
         bypass_skip=None,
-        **kwargs,
     ):
         """
         verbose=0 if you want no output
@@ -274,6 +293,7 @@ class ZestRunner:
             colon-delimited list to run certain kinds
             "unit" is assumed on all un-grouped tests.
         """
+        zest.reset()
         zest._disable_shuffle = disable_shuffle
 
         self.bypass_skip = bypass_skip
@@ -282,8 +302,14 @@ class ZestRunner:
         self.include_dirs = (include_dirs or "").split(":")
         self.timings = []
 
-        if groups is not None:
-            groups = groups.split(":")
+        # Execute root zests in group order
+        if run_groups is None:
+            run_groups = "*"
+        run_groups = run_groups.split(":")
+
+        if skip_groups is None:
+            skip_groups = ""
+        skip_groups = set(skip_groups.split(":"))
 
         # zest runner must start in the root of the project
         # so that modules may be loaded appropriately.
@@ -296,55 +322,60 @@ class ZestRunner:
                 path = os.path.join(curr, module_name + ".py")
                 with open(path) as f:
                     source = f.read()
-                    module_ast = ast.parse(source)
-                    zests = self._recurse_ast(module_ast.body, None)
 
-                    for full_name, member_groups in zests:
-                        # If the requested substring is anywhere in the full_name
-                        # then we add all the parents
-                        # eg:
-                        #  full_name = "zest_test1.it_does_y.it_does_y1"
-                        #  match_string = "it_does_y1"
-                        #  Then allow_to_run == [
-                        #    "zest_test1"
-                        #    "zest_test1.it_does_y"
-                        #    "zest_test1.it_does_y.it_does_y1"
-                        #  ]
+                module_ast = ast.parse(source)
+                zests = self._recurse_ast(module_ast.body, None, None)
 
-                        if match_string is None or match_string in full_name:
-                            parts = full_name.split(".")
-                            for i in range(len(parts)):
-                                allow_to_run += [".".join(parts[0 : i + 1])]
+                for full_name, member_groups, skips in zests:
+                    # If the requested substring is anywhere in the full_name
+                    # then we add all the parents
+                    # eg:
+                    #  full_name = "zest_test1.it_does_y.it_does_y1"
+                    #  match_string = "it_does_y1"
+                    #  Then allow_to_run == [
+                    #    "zest_test1"
+                    #    "zest_test1.it_does_y"
+                    #    "zest_test1.it_does_y.it_does_y1"
+                    #  ]
 
-                            if len(member_groups) == 0:
-                                # Default to run non-unit tests second
-                                member_groups = ["not_unit"]
+                    parts = full_name.split(".")
+                    sub_dirs = curr[len(root):].split(os.sep)
+                    package = ".".join(sub_dirs).lstrip("./")
+                    if len(member_groups) == 0:
+                        # Default to run non-unit tests second
+                        member_groups = set(["unit"])
 
-                            sub_dirs = curr[len(root) :].split(os.sep)
-                            package = ".".join(sub_dirs).lstrip("./")
-                            root_zest_funcs[parts[0]] = (
-                                module_name,
-                                package,
-                                member_groups,
-                            )
+                    if match_string is None or match_string in full_name:
+                        for i in range(len(parts)):
+                            allow_to_run += [".".join(parts[0 : i + 1])]
 
-        zest._allow_to_run = allow_to_run
+                    if len(parts) == 1:
+                        root_zest_funcs[parts[0]] = (
+                            module_name,
+                            package,
+                            member_groups,
+                        )
 
-        # Execute root zests in group order
-        if groups is None:
-            groups = ["unit", "not_unit"]
+        zest._allow_to_run = list(set(allow_to_run))
 
         has_run = {}
-        for group in groups:
-            if group != "*":
+        for run_group in run_groups:
+            if run_group != "*":
                 if self.verbose > 1:
-                    s(cyan, "\nStarting group ", bold, group)
+                    s(cyan, "\nStarting group ", bold, run_group)
 
             for (
                 root_name,
                 (module_name, package, member_groups),
             ) in root_zest_funcs.items():
-                if group in member_groups and not has_run.get(root_name):
+                is_test_in_a_skpped_group = len(member_groups & skip_groups) > 0
+
+                if is_test_in_a_skpped_group:
+                    self._test_start_callback(root_name, [], None)
+                    self._test_stop_callback(root_name, [], "skipped because it is in a skipped group", 0.0, None)
+                    continue
+
+                if (run_group in member_groups or run_group == "*") and not has_run.get(root_name):
                     imported = import_module("." + module_name, package=package)
                     func = getattr(imported, root_name)
 
@@ -389,11 +420,17 @@ def main():
         help="Colon-delimited list of directories to search",
     )
     parser.add_argument(
-        "--groups",
+        "--run_groups",
         type=str,
         nargs="?",
         help="Run these colon-delimited groups. If not specified, only zests with no group will run",
     )
+    parser.add_argument(
+        "--skip_groups",
+        type=str,
+        nargs="?",
+        help="Skip these colon-delimited groups.",
+    )
     parser.add_argument(
         "--disable_shuffle",
         action="store_true",
@@ -403,7 +440,7 @@ def main():
         "--version", action="store_true", help="Show version and exit",
     )
     parser.add_argument(
-        "--bypass_skip", nargs="?", help="Run even if skipped given skip tag",
+        "--bypass_skip", nargs="?", help="Run test even if it was skipped given this skip tag",
     )
     parser.add_argument(
         "match_string", type=str, nargs="?", help="Optional substring to match"
@@ -415,6 +452,7 @@ def main():
 
         print(__version__)
         sys.exit(0)
+    del kwargs["version"]
 
     runner = ZestRunner(**kwargs)
     sys.exit(runner.retcode)
